<?php
/**
 * Data Export for Authorities
 * Generates a full audit report of document signing activities
 * Restricted to administrative access only
 */

// Enable error reporting in development (disable in production)
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Required files
require_once 'db-config.php';
require_once 'eidas-compliance.php';

// Simple authentication - in production use a proper auth system
session_start();
$admin_password = 'i/chat/33f1d5f4'; // Change this!

// Check if logged in or trying to log in
if (!isset($_SESSION['admin_auth']) || $_SESSION['admin_auth'] !== true) {
    // Check for login attempt
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['password'])) {
        if ($_POST['password'] === $admin_password) {
            $_SESSION['admin_auth'] = true;
        } else {
            echo '<h2>Authentication failed</h2>';
            showLoginForm();
            exit;
        }
    } else {
        showLoginForm();
        exit;
    }
}

// Get document ID if specified
$document_id = isset($_GET['document_id']) ? filter_var($_GET['document_id'], FILTER_SANITIZE_STRING) : null;

// Handle export requests
if (isset($_GET['export']) && $_GET['export'] === 'pdf' && $document_id) {
    exportDocumentAsPdf($document_id);
    exit;
}

// Initialize eIDAS compliance module
$eidas = new EidasCompliance();

// Display header
?>
<!DOCTYPE html>
<html lang="ro">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Inkless-Flow - Export Date</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <style>
        body { padding: 20px; }
        .document-row { cursor: pointer; }
        .document-row:hover { background-color: #f8f9fa; }
    </style>
</head>
<body>
    <div class="container">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1>Inkless-Flow - Export Date</h1>
            <a href="?logout=1" class="btn btn-outline-secondary">Deconectare</a>
        </div>

<?php
// Check for logout
if (isset($_GET['logout'])) {
    session_destroy();
    header('Location: ' . $_SERVER['PHP_SELF']);
    exit;
}

// Display document list or single document details
if ($document_id) {
    displayDocumentDetails($document_id);
} else {
    displayDocumentList();
}

// Display footer
?>
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            $('.document-row').click(function() {
                window.location = '?document_id=' + $(this).data('id');
            });
        });
    </script>
</body>
</html>
<?php

/**
 * Display login form
 */
function showLoginForm() {
    ?>
    <!DOCTYPE html>
    <html lang="ro">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Inkless-Flow - Export Date - Autentificare</title>
        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
        <style>
            body {
                display: flex;
                align-items: center;
                justify-content: center;
                height: 100vh;
                background-color: #f8f9fa;
            }
            .login-form {
                width: 100%;
                max-width: 400px;
                padding: 15px;
                margin: auto;
            }
        </style>
    </head>
    <body>
        <div class="login-form">
            <h2 class="text-center mb-4">Acces Export Date</h2>
            <form method="post">
                <div class="form-group">
                    <label for="password">Parolă:</label>
                    <input type="password" class="form-control" id="password" name="password" required>
                </div>
                <button type="submit" class="btn btn-primary btn-block">Autentificare</button>
            </form>
        </div>
    </body>
    </html>
    <?php
}

/**
 * Display list of all documents
 */
function displayDocumentList() {
    global $db_conn;
    
    try {
        $stmt = $db_conn->prepare("
            SELECT 
                d.document_id, 
                d.file_name, 
                d.upload_timestamp, 
                d.status, 
                d.uploaded_by,
                s.signer_email,
                s.signature_timestamp,
                COUNT(a.log_id) AS activity_count
            FROM 
                documents d
            LEFT JOIN 
                signatures s ON d.document_id = s.document_id
            LEFT JOIN 
                audit_logs a ON d.document_id = a.document_id
            GROUP BY 
                d.document_id
            ORDER BY 
                d.created_at DESC
        ");
        
        $stmt->execute();
        $documents = $stmt->fetchAll();
        
        if (count($documents) === 0) {
            echo '<div class="alert alert-info">Nu există documente în baza de date.</div>';
            return;
        }
        
        ?>
        <div class="card mb-4">
            <div class="card-header">
                <h3 class="mb-0">Documente</h3>
            </div>
            <div class="card-body p-0">
                <table class="table table-hover mb-0">
                    <thead>
                        <tr>
                            <th>Nume fișier</th>
                            <th>Status</th>
                            <th>Încărcat de</th>
                            <th>Data încărcării</th>
                            <th>Semnat de</th>
                            <th>Data semnării</th>
                            <th>Activități</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($documents as $doc): ?>
                        <tr class="document-row" data-id="<?php echo htmlspecialchars($doc['document_id']); ?>">
                            <td><?php echo htmlspecialchars($doc['file_name']); ?></td>
                            <td>
                                <?php if ($doc['status'] === 'signed'): ?>
                                <span class="badge badge-success">Semnat</span>
                                <?php elseif ($doc['status'] === 'uploaded'): ?>
                                <span class="badge badge-warning">Nesemnat</span>
                                <?php else: ?>
                                <span class="badge badge-secondary"><?php echo htmlspecialchars($doc['status']); ?></span>
                                <?php endif; ?>
                            </td>
                            <td><?php echo htmlspecialchars($doc['uploaded_by']); ?></td>
                            <td><?php echo date('d.m.Y H:i', $doc['upload_timestamp']); ?></td>
                            <td><?php echo $doc['signer_email'] ? htmlspecialchars($doc['signer_email']) : '-'; ?></td>
                            <td><?php echo $doc['signature_timestamp'] ? date('d.m.Y H:i', $doc['signature_timestamp']) : '-'; ?></td>
                            <td><?php echo $doc['activity_count']; ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <?php
    } catch (PDOException $e) {
        echo '<div class="alert alert-danger">Eroare la preluarea datelor: ' . $e->getMessage() . '</div>';
    }
}

/**
 * Display details for a single document
 * 
 * @param string $document_id Document ID
 */
function displayDocumentDetails($document_id) {
    global $db_conn;
    
    try {
        // Get document details
        $stmt = $db_conn->prepare("
            SELECT 
                d.*,
                s.signature_id,
                s.signer_email,
                s.signature_timestamp,
                s.signature_timestamp_iso,
                s.signature_source,
                s.signature_ip,
                s.signature_data
            FROM 
                documents d
            LEFT JOIN 
                signatures s ON d.document_id = s.document_id
            WHERE 
                d.document_id = :doc_id
            LIMIT 1
        ");
        
        $stmt->bindParam(':doc_id', $document_id);
        $stmt->execute();
        $document = $stmt->fetch();
        
        if (!$document) {
            echo '<div class="alert alert-warning">Documentul nu a fost găsit.</div>';
            echo '<a href="' . $_SERVER['PHP_SELF'] . '" class="btn btn-primary">Înapoi la lista de documente</a>';
            return;
        }
        
        // Get audit logs
        $stmt = $db_conn->prepare("
            SELECT * FROM audit_logs 
            WHERE document_id = :doc_id 
            ORDER BY timestamp ASC
        ");
        
        $stmt->bindParam(':doc_id', $document_id);
        $stmt->execute();
        $auditLogs = $stmt->fetchAll();
        
        // Get OTP verifications
        $stmt = $db_conn->prepare("
            SELECT * FROM otp_verification 
            WHERE document_id = :doc_id 
            ORDER BY created_at ASC
        ");
        
        $stmt->bindParam(':doc_id', $document_id);
        $stmt->execute();
        $otpVerifications = $stmt->fetchAll();
        
        // Display document details
        ?>
        <div class="mb-3">
            <a href="<?php echo $_SERVER['PHP_SELF']; ?>" class="btn btn-outline-primary">&larr; Înapoi la lista de documente</a>
            <a href="?document_id=<?php echo urlencode($document_id); ?>&export=pdf" class="btn btn-success ml-2">Export PDF</a>
        </div>
        
        <div class="card mb-4">
            <div class="card-header">
                <h3 class="mb-0">Detalii document</h3>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-6">
                        <p><strong>Nume fișier:</strong> <?php echo htmlspecialchars($document['file_name']); ?></p>
                        <p><strong>ID Document (hash):</strong> <?php echo htmlspecialchars($document['document_id']); ?></p>
                        <p><strong>Status:</strong> 
                            <?php if ($document['status'] === 'signed'): ?>
                            <span class="badge badge-success">Semnat</span>
                            <?php elseif ($document['status'] === 'uploaded'): ?>
                            <span class="badge badge-warning">Nesemnat</span>
                            <?php else: ?>
                            <span class="badge badge-secondary"><?php echo htmlspecialchars($document['status']); ?></span>
                            <?php endif; ?>
                        </p>
                        <p><strong>Încărcat de:</strong> <?php echo htmlspecialchars($document['uploaded_by']); ?></p>
                        <p><strong>Data încărcării:</strong> <?php echo date('d.m.Y H:i:s', $document['upload_timestamp']); ?></p>
                        <p><strong>Dimensiune:</strong> <?php echo formatBytes($document['original_file_size']); ?></p>
                        <p><strong>Tip MIME:</strong> <?php echo htmlspecialchars($document['mime_type']); ?></p>
                    </div>
                    <div class="col-md-6">
                        <?php if ($document['signature_id']): ?>
                        <p><strong>Semnatură ID:</strong> <?php echo htmlspecialchars($document['signature_id']); ?></p>
                        <p><strong>Semnat de:</strong> <?php echo htmlspecialchars($document['signer_email']); ?></p>
                        <p><strong>Data semnării:</strong> <?php echo date('d.m.Y H:i:s', $document['signature_timestamp']); ?></p>
                        <p><strong>Timestamp ISO:</strong> <?php echo htmlspecialchars($document['signature_timestamp_iso']); ?></p>
                        <p><strong>Sursă timestamp:</strong> <?php echo htmlspecialchars($document['signature_source']); ?></p>
                        <p><strong>IP semnatar:</strong> <?php echo htmlspecialchars($document['signature_ip']); ?></p>
                        <?php else: ?>
                        <p><em>Acest document nu a fost încă semnat.</em></p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        
        <?php if ($document['signature_data']): ?>
        <div class="card mb-4">
            <div class="card-header">
                <h3 class="mb-0">Date semnătură</h3>
            </div>
            <div class="card-body">
                <pre><?php echo htmlspecialchars(json_encode(json_decode($document['signature_data']), JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE)); ?></pre>
            </div>
        </div>
        <?php endif; ?>
        
        <div class="card mb-4">
            <div class="card-header">
                <h3 class="mb-0">Verificări OTP</h3>
            </div>
            <div class="card-body">
                <?php if (count($otpVerifications) === 0): ?>
                <p>Nu există verificări OTP pentru acest document.</p>
                <?php else: ?>
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>Email</th>
                            <th>OTP</th>
                            <th>Creat la</th>
                            <th>Expiră la</th>
                            <th>Verificat</th>
                            <th>IP Verificare</th>
                            <th>Timestamp Verificare</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($otpVerifications as $otp): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($otp['email']); ?></td>
                            <td><?php echo htmlspecialchars($otp['otp']); ?></td>
                            <td><?php echo htmlspecialchars($otp['created_at']); ?></td>
                            <td><?php echo htmlspecialchars($otp['expires_at']); ?></td>
                            <td>
                                <?php if ($otp['verified']): ?>
                                <span class="badge badge-success">Da</span>
                                <?php else: ?>
                                <span class="badge badge-danger">Nu</span>
                                <?php endif; ?>
                            </td>
                            <td><?php echo $otp['verification_ip'] ? htmlspecialchars($otp['verification_ip']) : '-'; ?></td>
                            <td><?php echo $otp['verification_timestamp'] ? date('d.m.Y H:i:s', $otp['verification_timestamp']) : '-'; ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
                <?php endif; ?>
            </div>
        </div>
        
        <div class="card mb-4">
            <div class="card-header">
                <h3 class="mb-0">Jurnal de audit</h3>
            </div>
            <div class="card-body">
                <?php if (count($auditLogs) === 0): ?>
                <p>Nu există înregistrări de audit pentru acest document.</p>
                <?php else: ?>
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>Acțiune</th>
                            <th>Utilizator</th>
                            <th>Data și ora</th>
                            <th>IP</th>
                            <th>User Agent</th>
                            <th>Date adiționale</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($auditLogs as $log): ?>
                        <tr>
                            <td>
                                <?php
                                switch ($log['action']) {
                                    case 'document_uploaded':
                                        echo '<span class="badge badge-info">Încărcat</span>';
                                        break;
                                    case 'document_viewed':
                                        echo '<span class="badge badge-secondary">Vizualizat</span>';
                                        break;
                                    case 'otp_requested':
                                        echo '<span class="badge badge-primary">OTP Solicitat</span>';
                                        break;
                                    case 'otp_verified':
                                        echo '<span class="badge badge-warning">OTP Verificat</span>';
                                        break;
                                    case 'document_signed':
                                        echo '<span class="badge badge-success">Semnat</span>';
                                        break;
                                    case 'document_downloaded':
                                        echo '<span class="badge badge-dark">Descărcat</span>';
                                        break;
                                    case 'document_deleted':
                                        echo '<span class="badge badge-danger">Șters</span>';
                                        break;
                                    default:
                                        echo htmlspecialchars($log['action']);
                                }
                                ?>
                            </td>
                            <td><?php echo htmlspecialchars($log['user_email']); ?></td>
                            <td><?php echo date('d.m.Y H:i:s', $log['timestamp']); ?></td>
                            <td><?php echo htmlspecialchars($log['ip_address']); ?></td>
                            <td><?php echo $log['user_agent'] ? htmlspecialchars(substr($log['user_agent'], 0, 50) . '...') : '-'; ?></td>
                            <td><?php echo $log['additional_data'] ? htmlspecialchars(substr($log['additional_data'], 0, 30) . '...') : '-'; ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
                <?php endif; ?>
            </div>
        </div>
        <?php
    } catch (PDOException $e) {
        echo '<div class="alert alert-danger">Eroare la preluarea datelor: ' . $e->getMessage() . '</div>';
        echo '<a href="' . $_SERVER['PHP_SELF'] . '" class="btn btn-primary">Înapoi la lista de documente</a>';
    }
}

/**
 * Export document details as PDF
 * 
 * @param string $document_id Document ID
 */
function exportDocumentAsPdf($document_id) {
    global $db_conn;
    
    try {
        // Get document details
        $stmt = $db_conn->prepare("
            SELECT 
                d.*,
                s.signature_id,
                s.signer_email,
                s.signature_timestamp,
                s.signature_timestamp_iso,
                s.signature_source,
                s.signature_ip,
                s.signature_data
            FROM 
                documents d
            LEFT JOIN 
                signatures s ON d.document_id = s.document_id
            WHERE 
                d.document_id = :doc_id
            LIMIT 1
        ");
        
        $stmt->bindParam(':doc_id', $document_id);
        $stmt->execute();
        $document = $stmt->fetch();
        
        if (!$document) {
            header('Content-Type: text/html; charset=UTF-8');
            echo '<div class="alert alert-warning">Documentul nu a fost găsit.</div>';
            echo '<a href="' . $_SERVER['PHP_SELF'] . '" class="btn btn-primary">Înapoi la lista de documente</a>';
            return;
        }
        
        // Get audit logs
        $stmt = $db_conn->prepare("
            SELECT * FROM audit_logs 
            WHERE document_id = :doc_id 
            ORDER BY timestamp ASC
        ");
        
        $stmt->bindParam(':doc_id', $document_id);
        $stmt->execute();
        $auditLogs = $stmt->fetchAll();
        
        // Get OTP verifications
        $stmt = $db_conn->prepare("
            SELECT * FROM otp_verification 
            WHERE document_id = :doc_id 
            ORDER BY created_at ASC
        ");
        
        $stmt->bindParam(':doc_id', $document_id);
        $stmt->execute();
        $otpVerifications = $stmt->fetchAll();
        
        // Check if TCPDF is available
        if (!class_exists('TCPDF')) {
            // Create PDF with simpler method - using mPDF or direct HTML output
            exportAsHTML($document, $auditLogs, $otpVerifications);
            return;
        }
        
        // Create PDF using TCPDF
        $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        
        // Set document information
        $pdf->SetCreator('Inkless-Flow');
        $pdf->SetAuthor('Inkless-Flow eIDAS System');
        $pdf->SetTitle('Document Audit Report - ' . $document['file_name']);
        $pdf->SetSubject('eIDAS Compliance Report');
        $pdf->SetKeywords('eIDAS, electronic signature, audit, report');
        
        // Set default header data
        $pdf->SetHeaderData('', 0, 'Inkless-Flow eIDAS Compliance Report', 'Document Audit Report - Generated on ' . date('Y-m-d H:i:s'));
        
        // Set header and footer fonts
        $pdf->setHeaderFont(Array('helvetica', '', 10));
        $pdf->setFooterFont(Array('helvetica', '', 8));
        
        // Set default monospaced font
        $pdf->SetDefaultMonospacedFont('courier');
        
        // Set margins
        $pdf->SetMargins(15, 20, 15);
        $pdf->SetHeaderMargin(5);
        $pdf->SetFooterMargin(10);
        
        // Set auto page breaks
        $pdf->SetAutoPageBreak(TRUE, 15);
        
        // Set image scale factor
        $pdf->setImageScale(1.25);
        
        // Add a page
        $pdf->AddPage();
        
        // Set font
        $pdf->SetFont('helvetica', 'B', 16);
        
        // Document title
        $pdf->Cell(0, 10, 'Document Audit Report', 0, 1, 'C');
        $pdf->SetFont('helvetica', '', 10);
        $pdf->Cell(0, 5, 'Generated on ' . date('Y-m-d H:i:s'), 0, 1, 'C');
        $pdf->Ln(10);
        
        // Document details
        $pdf->SetFont('helvetica', 'B', 14);
        $pdf->Cell(0, 10, 'Document Details', 0, 1, 'L');
        $pdf->SetFont('helvetica', '', 10);
        
        // Document details table
        $pdf->SetFillColor(240, 240, 240);
        $pdf->Cell(60, 7, 'File Name:', 1, 0, 'L', true);
        $pdf->Cell(120, 7, $document['file_name'], 1, 1, 'L');
        
        $pdf->Cell(60, 7, 'Document ID (Hash):', 1, 0, 'L', true);
        $pdf->Cell(120, 7, $document['document_id'], 1, 1, 'L');
        
        $pdf->Cell(60, 7, 'Status:', 1, 0, 'L', true);
        $pdf->Cell(120, 7, $document['status'], 1, 1, 'L');
        
        $pdf->Cell(60, 7, 'Uploaded By:', 1, 0, 'L', true);
        $pdf->Cell(120, 7, $document['uploaded_by'], 1, 1, 'L');
        
        $pdf->Cell(60, 7, 'Upload Date:', 1, 0, 'L', true);
        $pdf->Cell(120, 7, date('Y-m-d H:i:s', $document['upload_timestamp']), 1, 1, 'L');
        
        $pdf->Cell(60, 7, 'File Size:', 1, 0, 'L', true);
        $pdf->Cell(120, 7, formatBytes($document['original_file_size']), 1, 1, 'L');
        
        $pdf->Cell(60, 7, 'MIME Type:', 1, 0, 'L', true);
        $pdf->Cell(120, 7, $document['mime_type'], 1, 1, 'L');
        
        $pdf->Ln(5);
        
        // Signature details if available
        if ($document['signature_id']) {
            $pdf->SetFont('helvetica', 'B', 14);
            $pdf->Cell(0, 10, 'Signature Details', 0, 1, 'L');
            $pdf->SetFont('helvetica', '', 10);
            
            $pdf->Cell(60, 7, 'Signature ID:', 1, 0, 'L', true);
            $pdf->Cell(120, 7, $document['signature_id'], 1, 1, 'L');
            
            $pdf->Cell(60, 7, 'Signed By:', 1, 0, 'L', true);
            $pdf->Cell(120, 7, $document['signer_email'], 1, 1, 'L');
            
            $pdf->Cell(60, 7, 'Signature Date:', 1, 0, 'L', true);
            $pdf->Cell(120, 7, date('Y-m-d H:i:s', $document['signature_timestamp']), 1, 1, 'L');
            
            $pdf->Cell(60, 7, 'Timestamp ISO:', 1, 0, 'L', true);
            $pdf->Cell(120, 7, $document['signature_timestamp_iso'], 1, 1, 'L');
            
            $pdf->Cell(60, 7, 'Timestamp Source:', 1, 0, 'L', true);
            $pdf->Cell(120, 7, $document['signature_source'], 1, 1, 'L');
            
            $pdf->Cell(60, 7, 'Signer IP:', 1, 0, 'L', true);
            $pdf->Cell(120, 7, $document['signature_ip'], 1, 1, 'L');
            
            $pdf->Ln(5);
            
            // Signature data if available
            if ($document['signature_data']) {
                $pdf->SetFont('helvetica', 'B', 14);
                $pdf->Cell(0, 10, 'Signature Data', 0, 1, 'L');
                $pdf->SetFont('courier', '', 8);
                
                $signatureData = json_decode($document['signature_data'], true);
                $formattedData = json_encode($signatureData, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE);
                $pdf->MultiCell(0, 5, $formattedData, 0, 'L');
                
                $pdf->Ln(5);
            }
        }
        
        // OTP verifications
        if (count($otpVerifications) > 0) {
            $pdf->AddPage();
            $pdf->SetFont('helvetica', 'B', 14);
            $pdf->Cell(0, 10, 'OTP Verifications', 0, 1, 'L');
            $pdf->SetFont('helvetica', '', 10);
            
            $pdf->SetFillColor(220, 220, 220);
            $pdf->Cell(40, 7, 'Email', 1, 0, 'C', true);
            $pdf->Cell(20, 7, 'OTP', 1, 0, 'C', true);
            $pdf->Cell(35, 7, 'Created', 1, 0, 'C', true);
            $pdf->Cell(35, 7, 'Expires', 1, 0, 'C', true);
            $pdf->Cell(20, 7, 'Verified', 1, 0, 'C', true);
            $pdf->Cell(30, 7, 'IP', 1, 1, 'C', true);
            
            $pdf->SetFont('helvetica', '', 8);
            foreach ($otpVerifications as $otp) {
                $pdf->Cell(40, 6, $otp['email'], 1, 0, 'L');
                $pdf->Cell(20, 6, $otp['otp'], 1, 0, 'C');
                $pdf->Cell(35, 6, $otp['created_at'], 1, 0, 'C');
                $pdf->Cell(35, 6, $otp['expires_at'], 1, 0, 'C');
                $pdf->Cell(20, 6, $otp['verified'] ? 'Yes' : 'No', 1, 0, 'C');
                $pdf->Cell(30, 6, $otp['verification_ip'] ? $otp['verification_ip'] : '-', 1, 1, 'L');
            }
            
            $pdf->Ln(5);
        }
        
        // Audit logs
        if (count($auditLogs) > 0) {
            $pdf->AddPage();
            $pdf->SetFont('helvetica', 'B', 14);
            $pdf->Cell(0, 10, 'Audit Log', 0, 1, 'L');
            $pdf->SetFont('helvetica', '', 10);
            
            $pdf->SetFillColor(220, 220, 220);
            $pdf->Cell(25, 7, 'Action', 1, 0, 'C', true);
            $pdf->Cell(40, 7, 'User', 1, 0, 'C', true);
            $pdf->Cell(35, 7, 'Date & Time', 1, 0, 'C', true);
            $pdf->Cell(30, 7, 'IP Address', 1, 0, 'C', true);
            $pdf->Cell(50, 7, 'Additional Data', 1, 1, 'C', true);
            
            $pdf->SetFont('helvetica', '', 8);
            foreach ($auditLogs as $log) {
                // Format action
                switch ($log['action']) {
                    case 'document_uploaded':
                        $action = 'Upload';
                        break;
                    case 'document_viewed':
                        $action = 'View';
                        break;
                    case 'otp_requested':
                        $action = 'OTP Request';
                        break;
                    case 'otp_verified':
                        $action = 'OTP Verify';
                        break;
                    case 'document_signed':
                        $action = 'Sign';
                        break;
                    case 'document_downloaded':
                        $action = 'Download';
                        break;
                    case 'document_deleted':
                        $action = 'Delete';
                        break;
                    default:
                        $action = $log['action'];
                }
                
                // Format timestamp
                $timestamp = date('Y-m-d H:i:s', $log['timestamp']);
                
                // Format additional data
                $additionalData = $log['additional_data'] ? substr($log['additional_data'], 0, 40) : '-';
                
                $pdf->Cell(25, 6, $action, 1, 0, 'L');
                $pdf->Cell(40, 6, $log['user_email'], 1, 0, 'L');
                $pdf->Cell(35, 6, $timestamp, 1, 0, 'C');
                $pdf->Cell(30, 6, $log['ip_address'], 1, 0, 'L');
                $pdf->Cell(50, 6, $additionalData, 1, 1, 'L');
            }
        }
        
        // eIDAS compliance information
        $pdf->AddPage();
        $pdf->SetFont('helvetica', 'B', 14);
        $pdf->Cell(0, 10, 'eIDAS Compliance Information', 0, 1, 'L');
        $pdf->SetFont('helvetica', '', 10);
        
        $pdf->MultiCell(0, 7, 'This document and its associated electronic signature comply with eIDAS Regulation (EU) No 910/2014 requirements for Simple Electronic Signatures (SES). The following measures have been implemented:', 0, 'L');
        
        $pdf->Ln(5);
        
        $eidas_points = [
            'Document Integrity: SHA-256 hash generated at upload to ensure document has not been altered',
            'User Authentication: Email verification using time-limited OTP codes',
            'Trusted Timestamps: Timestamps obtained from reliable sources including WorldTimeAPI.org',
            'Signature Generation: Compliant with eIDAS standards using HMAC-SHA256',
            'Audit Trail: Complete chronological record of all actions taken on this document',
            'Data Protection: All data stored in compliance with GDPR requirements'
        ];
        
        foreach ($eidas_points as $point) {
            $pdf->SetFont('zapfdingbats', '', 10);
            $pdf->Cell(5, 5, '✓', 0, 0);
            $pdf->SetFont('helvetica', '', 10);
            $pdf->MultiCell(0, 5, $point, 0, 'L');
            $pdf->Ln(2);
        }
        
        $pdf->Ln(5);
        $pdf->SetFont('helvetica', 'B', 10);
        $pdf->Cell(0, 7, 'Legal Notice:', 0, 1, 'L');
        $pdf->SetFont('helvetica', 'I', 9);
        $pdf->MultiCell(0, 5, 'Simple Electronic Signatures (SES) do not have the same legal weight as Qualified Electronic Signatures (QES) under eIDAS. For higher assurance, consider using a qualified trust service provider for Qualified Electronic Signatures.', 0, 'L');
        
        $pdf->Ln(10);
        $pdf->SetFont('helvetica', 'B', 10);
        $pdf->Cell(0, 7, 'Verification Information:', 0, 1, 'L');
        $pdf->SetFont('helvetica', '', 9);
        $pdf->MultiCell(0, 5, 'To verify this report, please contact the system administrator at admin@inkless-flow.com with the Document ID: ' . $document_id, 0, 'L');
        
        // Output the PDF
        $filename = 'eIDAS_Compliance_Report_' . substr($document_id, 0, 8) . '.pdf';
        $pdf->Output($filename, 'D');
        exit;
    } catch (PDOException $e) {
        header('Content-Type: text/html; charset=UTF-8');
        echo '<div class="alert alert-danger">Eroare la preluarea datelor pentru export: ' . $e->getMessage() . '</div>';
        echo '<a href="?document_id=' . urlencode($document_id) . '" class="btn btn-primary">Înapoi la detalii document</a>';
    }
}

/**
 * Format bytes to readable size
 * 
 * @param int $bytes Number of bytes
 * @param int $precision Number of decimal places
 * @return string Formatted size
 */
function formatBytes($bytes, $precision = 2) {
    $units = ['B', 'KB', 'MB', 'GB', 'TB'];
    
    $bytes = max($bytes, 0);
    $pow = floor(($bytes ? log($bytes) : 0) / log(1024));
    $pow = min($pow, count($units) - 1);
    
    $bytes /= pow(1024, $pow);
    
    return round($bytes, $precision) . ' ' . $units[$pow];
}

/**
 * Export document details as HTML if PDF generation fails
 * 
 * @param array $document Document details
 * @param array $auditLogs Audit logs
 * @param array $otpVerifications OTP verifications
 */
function exportAsHTML($document, $auditLogs, $otpVerifications) {
    header('Content-Type: text/html; charset=UTF-8');
    header('Content-Disposition: attachment; filename="eIDAS_Report_' . substr($document['document_id'], 0, 8) . '.html"');
    
    ?>
    <!DOCTYPE html>
    <html lang="ro">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>eIDAS Compliance Report</title>
        <style>
            body {
                font-family: Arial, sans-serif;
                line-height: 1.6;
                color: #333;
                max-width: 1200px;
                margin: 0 auto;
                padding: 20px;
            }
            h1, h2, h3 {
                color: #2c3e50;
            }
            table {
                width: 100%;
                border-collapse: collapse;
                margin-bottom: 20px;
            }
            th, td {
                border: 1px solid #ddd;
                padding: 8px;
                text-align: left;
            }
            th {
                background-color: #f5f5f5;
                font-weight: bold;
            }
            tr:nth-child(even) {
                background-color: #f9f9f9;
            }
            .header {
                text-align: center;
                margin-bottom: 30px;
                padding-bottom: 20px;
                border-bottom: 1px solid #eee;
            }
            .section {
                margin-bottom: 30px;
                padding-bottom: 20px;
                border-bottom: 1px solid #eee;
            }
            .badge {
                display: inline-block;
                padding: 3px 7px;
                border-radius: 3px;
                font-size: 12px;
                font-weight: bold;
                color: white;
            }
            .badge-info { background-color: #3498db; }
            .badge-success { background-color: #2ecc71; }
            .badge-warning { background-color: #f39c12; }
            .badge-danger { background-color: #e74c3c; }
            .badge-secondary { background-color: #7f8c8d; }
            .badge-dark { background-color: #34495e; }
            .footer {
                margin-top: 50px;
                padding-top: 20px;
                border-top: 1px solid #eee;
                font-size: 12px;
                color: #7f8c8d;
                text-align: center;
            }
        </style>
    </head>
    <body>
        <div class="header">
            <h1>Inkless-Flow eIDAS Compliance Report</h1>
            <p>Generated on <?php echo date('Y-m-d H:i:s'); ?></p>
        </div>
        
        <div class="section">
            <h2>Document Details</h2>
            <table>
                <tr>
                    <th width="30%">File Name</th>
                    <td><?php echo htmlspecialchars($document['file_name']); ?></td>
                </tr>
                <tr>
                    <th>Document ID (Hash)</th>
                    <td><?php echo htmlspecialchars($document['document_id']); ?></td>
                </tr>
                <tr>
                    <th>Status</th>
                    <td>
                        <?php if ($document['status'] === 'signed'): ?>
                        <span class="badge badge-success">Signed</span>
                        <?php elseif ($document['status'] === 'uploaded'): ?>
                        <span class="badge badge-warning">Unsigned</span>
                        <?php else: ?>
                        <span class="badge badge-secondary"><?php echo htmlspecialchars($document['status']); ?></span>
                        <?php endif; ?>
                    </td>
                </tr>
                <tr>
                    <th>Uploaded By</th>
                    <td><?php echo htmlspecialchars($document['uploaded_by']); ?></td>
                </tr>
                <tr>
                    <th>Upload Date</th>
                    <td><?php echo date('Y-m-d H:i:s', $document['upload_timestamp']); ?></td>
                </tr>
                <tr>
                    <th>File Size</th>
                    <td><?php echo formatBytes($document['original_file_size']); ?></td>
                </tr>
                <tr>
                    <th>MIME Type</th>
                    <td><?php echo htmlspecialchars($document['mime_type']); ?></td>
                </tr>
            </table>
        </div>
        
        <?php if ($document['signature_id']): ?>
        <div class="section">
            <h2>Signature Details</h2>
            <table>
                <tr>
                    <th width="30%">Signature ID</th>
                    <td><?php echo htmlspecialchars($document['signature_id']); ?></td>
                </tr>
                <tr>
                    <th>Signed By</th>
                    <td><?php echo htmlspecialchars($document['signer_email']); ?></td>
                </tr>
                <tr>
                    <th>Signature Date</th>
                    <td><?php echo date('Y-m-d H:i:s', $document['signature_timestamp']); ?></td>
                </tr>
                <tr>
                    <th>Timestamp ISO</th>
                    <td><?php echo htmlspecialchars($document['signature_timestamp_iso']); ?></td>
                </tr>
                <tr>
                    <th>Timestamp Source</th>
                    <td><?php echo htmlspecialchars($document['signature_source']); ?></td>
                </tr>
                <tr>
                    <th>Signer IP</th>
                    <td><?php echo htmlspecialchars($document['signature_ip']); ?></td>
                </tr>
            </table>
        </div>
        <?php endif; ?>
        
        <?php if ($document['signature_data']): ?>
        <div class="section">
            <h2>Signature Data</h2>
            <pre><?php echo htmlspecialchars(json_encode(json_decode($document['signature_data']), JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE)); ?></pre>
        </div>
        <?php endif; ?>
        
        <div class="section">
            <h2>OTP Verifications</h2>
            <?php if (count($otpVerifications) === 0): ?>
            <p>No OTP verifications for this document.</p>
            <?php else: ?>
            <table>
                <thead>
                    <tr>
                        <th>Email</th>
                        <th>OTP</th>
                        <th>Created</th>
                        <th>Expires</th>
                        <th>Verified</th>
                        <th>IP</th>
                        <th>Verification Time</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($otpVerifications as $otp): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($otp['email']); ?></td>
                        <td><?php echo htmlspecialchars($otp['otp']); ?></td>
                        <td><?php echo htmlspecialchars($otp['created_at']); ?></td>
                        <td><?php echo htmlspecialchars($otp['expires_at']); ?></td>
                        <td>
                            <?php if ($otp['verified']): ?>
                            <span class="badge badge-success">Yes</span>
                            <?php else: ?>
                            <span class="badge badge-danger">No</span>
                            <?php endif; ?>
                        </td>
                        <td><?php echo $otp['verification_ip'] ? htmlspecialchars($otp['verification_ip']) : '-'; ?></td>
                        <td><?php echo $otp['verification_timestamp'] ? date('Y-m-d H:i:s', $otp['verification_timestamp']) : '-'; ?></td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
            <?php endif; ?>
        </div>
        
        <div class="section">
            <h2>Audit Log</h2>
            <?php if (count($auditLogs) === 0): ?>
            <p>No audit logs for this document.</p>
            <?php else: ?>
            <table>
                <thead>
                    <tr>
                        <th>Action</th>
                        <th>User</th>
                        <th>Date & Time</th>
                        <th>IP</th>
                        <th>User Agent</th>
                        <th>Additional Data</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($auditLogs as $log): ?>
                    <tr>
                        <td>
                            <?php
                            switch ($log['action']) {
                                case 'document_uploaded':
                                    echo '<span class="badge badge-info">Upload</span>';
                                    break;
                                case 'document_viewed':
                                    echo '<span class="badge badge-secondary">View</span>';
                                    break;
                                case 'otp_requested':
                                    echo '<span class="badge badge-info">OTP Request</span>';
                                    break;
                                case 'otp_verified':
                                    echo '<span class="badge badge-warning">OTP Verify</span>';
                                    break;
                                case 'document_signed':
                                    echo '<span class="badge badge-success">Sign</span>';
                                    break;
                                case 'document_downloaded':
                                    echo '<span class="badge badge-dark">Download</span>';
                                    break;
                                case 'document_deleted':
                                    echo '<span class="badge badge-danger">Delete</span>';
                                    break;
                                default:
                                    echo htmlspecialchars($log['action']);
                            }
                            ?>
                        </td>
                        <td><?php echo htmlspecialchars($log['user_email']); ?></td>
                        <td><?php echo date('Y-m-d H:i:s', $log['timestamp']); ?></td>
                        <td><?php echo htmlspecialchars($log['ip_address']); ?></td>
                        <td><?php echo $log['user_agent'] ? htmlspecialchars(substr($log['user_agent'], 0, 50) . '...') : '-'; ?></td>
                        <td><?php echo $log['additional_data'] ? htmlspecialchars(substr($log['additional_data'], 0, 30) . '...') : '-'; ?></td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
            <?php endif; ?>
        </div>
        
        <div class="section">
            <h2>eIDAS Compliance Information</h2>
            <p>This document and its associated electronic signature comply with eIDAS Regulation (EU) No 910/2014 requirements for Simple Electronic Signatures (SES). The following measures have been implemented:</p>
            
            <ul>
                <li><strong>Document Integrity:</strong> SHA-256 hash generated at upload to ensure document has not been altered</li>
                <li><strong>User Authentication:</strong> Email verification using time-limited OTP codes</li>
                <li><strong>Trusted Timestamps:</strong> Timestamps obtained from reliable sources including WorldTimeAPI.org</li>
                <li><strong>Signature Generation:</strong> Compliant with eIDAS standards using HMAC-SHA256</li>
                <li><strong>Audit Trail:</strong> Complete chronological record of all actions taken on this document</li>
                <li><strong>Data Protection:</strong> All data stored in compliance with GDPR requirements</li>
            </ul>
            
            <p><strong>Legal Notice:</strong> <em>Simple Electronic Signatures (SES) do not have the same legal weight as Qualified Electronic Signatures (QES) under eIDAS. For higher assurance, consider using a qualified trust service provider for Qualified Electronic Signatures.</em></p>
        </div>
        
        <div class="footer">
            <p>Inkless-Flow eIDAS Compliance Report - Generated on <?php echo date('Y-m-d H:i:s'); ?></p>
            <p>To verify this report, please contact the system administrator at admin@inkless-flow.com with the Document ID: <?php echo htmlspecialchars($document['document_id']); ?></p>
        </div>
    </body>
    </html>
    <?php
}