<?php
/**
 * OTP Test Utility - FOR DEVELOPMENT ONLY
 * This file should be removed in production environments
 */

// Set headers for JSON response
header('Content-Type: application/json');

// Check for development mode
$is_dev = (isset($_SERVER['SERVER_NAME']) && (
    strpos($_SERVER['SERVER_NAME'], 'localhost') !== false ||
    strpos($_SERVER['SERVER_NAME'], '127.0.0.1') !== false ||
    strpos($_SERVER['SERVER_NAME'], '.test') !== false ||
    strpos($_SERVER['SERVER_NAME'], '.local') !== false
));

if (!$is_dev) {
    http_response_code(403);
    echo json_encode(['error' => 'This utility is only available in development environments']);
    exit;
}

require_once 'config.php';
require_once 'db-config.php';

// Create logs directory if it doesn't exist
if (!is_dir(LOG_DIR)) {
    mkdir(LOG_DIR, 0755, true);
}

// Function to generate OTP
function generateOTP($length = 6) {
    $otp = '';
    for ($i = 0; $i < $length; $i++) {
        $otp .= mt_rand(0, 9);
    }
    return $otp;
}

// Get parameters
$email = isset($_GET['email']) ? filter_var($_GET['email'], FILTER_SANITIZE_EMAIL) : 'test@example.com';
$document_id = isset($_GET['document_id']) ? $_GET['document_id'] : 'test_document_001';

// Generate OTP
$otp = generateOTP(6);

// Store in database
try {
    // Generate a key for rate limiting
    $ip = $_SERVER['REMOTE_ADDR'];
    $rate_key = md5($ip . $email);
    
    // Store in database
    $stmt = $db_conn->prepare("
        INSERT INTO otp_requests (
            email, otp, document_id, request_key, request_time, expires_at
        ) VALUES (
            :email, :otp, :doc_id, :key, :time, :expires
        )
    ");
    
    $now = time();
    $expires = $now + (5 * 60); // 5 minutes
    
    $stmt->bindParam(':email', $email);
    $stmt->bindParam(':otp', $otp);
    $stmt->bindParam(':doc_id', $document_id);
    $stmt->bindParam(':key', $rate_key);
    $stmt->bindParam(':time', $now);
    $stmt->bindParam(':expires', $expires);
    
    $db_success = $stmt->execute();
    
    // Save to a development file
    $dev_log = LOG_DIR . '/development_otps.txt';
    $dev_entry = date('Y-m-d H:i:s') . " - Email: $email, OTP: $otp, Document: $document_id, Expires: " . date('Y-m-d H:i:s', $expires) . "\n";
    file_put_contents($dev_log, $dev_entry, FILE_APPEND);
    
    // Provide response
    echo json_encode([
        'success' => true,
        'message' => 'OTP generated for testing',
        'email' => $email,
        'otp' => $otp,
        'document_id' => $document_id,
        'expires_at' => date('Y-m-d H:i:s', $expires),
        'db_stored' => $db_success ? 'yes' : 'no',
        'dev_file' => $dev_log
    ]);
    
} catch (Exception $e) {
    // Log error
    $error_log = LOG_DIR . '/test_otp_errors.log';
    $error_entry = date('Y-m-d H:i:s') . " - Error: " . $e->getMessage() . "\n";
    file_put_contents($error_log, $error_entry, FILE_APPEND);
    
    // Still provide the OTP for testing
    echo json_encode([
        'success' => false,
        'message' => 'Error storing OTP in database: ' . $e->getMessage(),
        'email' => $email,
        'otp' => $otp,
        'document_id' => $document_id,
        'fallback' => true
    ]);
}